@@ -11,7 +11,7 @@
 #include <myrrh/assert.h>
 #include <myrrh/seqan_boost_range_adaptors.h>
 
-#include <seqan.h>
+#include <seqan/index.h>
 #include <seqan/version.h>
 
 #include <boost/foreach.hpp>
