@@ -16,6 +16,8 @@
 
 #include <seqan/stream.h>
 #include <seqan/index/index_sa_lss.h>
+#include <seqan/seq_io/guess_stream_format.h> // had to add these 2 lines for it to compile with latest
+#include <seqan/seq_io/read_fasta_fastq.h>    // svn trunk: rev12932
 
 using namespace boost;
 using namespace std;
