@@ -7,7 +7,10 @@ Code to run MEME algorithm.
 """
 
 
-import subprocess, re, time, warnings
+import subprocess
+import re
+import time
+import warnings
 from cookbook.interval import Interval
 from stempy import ensure_dir_exists, logging, os, parse_options
 from cookbook.named_tuple import namedtuple
@@ -15,9 +18,8 @@ from cookbook.named_tuple import namedtuple
 
 logger = logging.getLogger(__name__)
 
-Start = namedtuple('Start', 'w0 nsites0 cons0 cons w nsites sig em_time niters cons_after_em')
-
-
+Start = namedtuple(
+    'Start', 'w0 nsites0 cons0 cons w nsites sig em_time niters cons_after_em')
 
 
 if False:
@@ -27,8 +29,6 @@ else:
     _meme_binary = '/home/john/local/bin/meme.bin'
 
 
-
-
 def run_meme(fasta, options, extra_args=None):
     """
     Runs MEME.
@@ -52,19 +52,19 @@ def run_meme(fasta, options, extra_args=None):
         #'-spfuzz', '0.5',
     ]
     if hasattr(options, 'max_iters') and options.max_iters:
-        meme_cmd_args += [ '-maxiter', str(options.max_iters) ]
+        meme_cmd_args += ['-maxiter', str(options.max_iters)]
     if hasattr(options, 'W') and options.W:
-        meme_cmd_args += [ '-w', str(options.W) ]
+        meme_cmd_args += ['-w', str(options.W)]
     if hasattr(options, 'min_w') and options.min_w:
-        meme_cmd_args += [ '-minw', str(options.min_w) ]
+        meme_cmd_args += ['-minw', str(options.min_w)]
     if hasattr(options, 'max_w') and options.max_w:
-        meme_cmd_args += [ '-maxw', str(options.max_w) ]
+        meme_cmd_args += ['-maxw', str(options.max_w)]
     if hasattr(options, 'min_num_sites') and options.min_num_sites:
-        meme_cmd_args += [ '-minsites', str(options.min_num_sites) ]
+        meme_cmd_args += ['-minsites', str(options.min_num_sites)]
     if hasattr(options, 'max_num_sites') and options.max_num_sites:
-        meme_cmd_args += [ '-maxsites', str(options.max_num_sites) ]
+        meme_cmd_args += ['-maxsites', str(options.max_num_sites)]
     if hasattr(options, 'num_motifs') and options.num_motifs:
-        meme_cmd_args += [ '-nmotifs', str(options.num_motifs) ]
+        meme_cmd_args += ['-nmotifs', str(options.num_motifs)]
     if extra_args:
         meme_cmd_args += extra_args
 
@@ -90,9 +90,12 @@ def run_meme(fasta, options, extra_args=None):
 
     # look for start points in stdout
     #component_re = re.compile('component\s+(\d+): lambda=\s+([0-9.]+) ps=\s+([0-9.]+) cons0=(\w+) score=([0-9.]+)')
-    start_re = re.compile('\(start\)\s+([0-9]+)\s+([0-9.]+)\s+(\w+)\s+-->\s+(\w+)\s+w\s+([0-9]+)\s+nsites\s+([0-9.]+)\s+sig\s+([0-9.]+|inf)')
-    em_time_re = re.compile('EM \(without discretization\) took ([0-9.]+) seconds for ([0-9]+) iterations. Final consensus: ([ACGTX]+)')
-    theta_re = re.compile('\s+(0\.[0-9]+)\s+(0\.[0-9]+)\s+(0\.[0-9]+)\s+(0\.[0-9]+)')
+    start_re = re.compile(
+        '\(start\)\s+([0-9]+)\s+([0-9.]+)\s+(\w+)\s+-->\s+(\w+)\s+w\s+([0-9]+)\s+nsites\s+([0-9.]+)\s+sig\s+([0-9.]+|inf)')
+    em_time_re = re.compile(
+        'EM \(without discretization\) took ([0-9.]+) seconds for ([0-9]+) iterations. Final consensus: ([ACGTX]+)')
+    theta_re = re.compile(
+        '\s+(0\.[0-9]+)\s+(0\.[0-9]+)\s+(0\.[0-9]+)\s+(0\.[0-9]+)')
     lambda_re = re.compile('lambda= (0\.[0-9]+) \(theta and obs\)')
     starts = []
     Zs = []
@@ -110,23 +113,23 @@ def run_meme(fasta, options, extra_args=None):
             niters = int(match.group(2))
             cons_after_em = match.group(3)
             logging.info(cons_after_em)
-            
+
 #        if l.startswith('component'):
 #            match = component_re.match(l)
 #            if not match:
 #                raise ValueError('Could not parse start line: %s', l)
 #            logger.debug('Got MEME start point from MEME output file\n%s', l)
-#            #w0, num_sites, start_cons, model_cons, w, num_sites_dis, sig = match.groups()
-#            #model_cons, start_cons = match.groups()
+# w0, num_sites, start_cons, model_cons, w, num_sites_dis, sig = match.groups()
+# model_cons, start_cons = match.groups()
 #            component, lambda_, ps, start_cons, start_score = match.groups()
 #            component = int(component)
 #            ps = float(ps)
 #            lambda_ = float(lambda_)
 #            start_score = float(start_score)
-#            #w0 = int(w0)
-#            #num_sites = float(num_sites)
-#            #w = int(w)
-#            #num_sites_dis = int(num_sites_dis)
+# w0 = int(w0)
+# num_sites = float(num_sites)
+# w = int(w)
+# num_sites_dis = int(num_sites_dis)
 #            start = Start(component=component, seed=start_cons, ps=ps, lambda_=lambda_, score=start_score)
 #            logger.info('MEME start: %s; num_sites=%.1f', start, start.ps * start.lambda_)
 #            starts.append(start)
@@ -142,10 +145,12 @@ def run_meme(fasta, options, extra_args=None):
             w = int(match.group(5))
             nsites = float(match.group(6))
             sig = float(match.group(7))
-            start = Start(w0=w0, nsites0=nsites0, cons0=cons0, cons=cons, w=w, nsites=nsites, sig=sig, em_time=em_time, niters=niters, cons_after_em=cons_after_em)
+            start = Start(
+                w0=w0, nsites0=nsites0, cons0=cons0, cons=cons, w=w, nsites=nsites,
+                sig=sig, em_time=em_time, niters=niters, cons_after_em=cons_after_em)
             logger.info('EM start: %s', start)
             starts.append(start)
-            #print w0, nsites0, cons0, cons, w, nsites, sig
+            # print w0, nsites0, cons0, cons, w, nsites, sig
         elif l.startswith('Z_ij: '):
             if l.startswith('Z_ij: lambda'):
                 Zs.append(dict())
@@ -166,11 +171,9 @@ def run_meme(fasta, options, extra_args=None):
             match = lambda_re.match(l)
             if match:
                 lambdas.append(float(match.group(1)))
-                
 
 #    if len(em_infos) != len(starts):
 #        raise RuntimeError('Should have found same number of starts as EM infos.')
-    
     # return details
     logger.debug('Finished running MEME')
     if len(Zs) != len(thetas):
@@ -180,8 +183,8 @@ def run_meme(fasta, options, extra_args=None):
     return meme_cmd_args, stdoutdata, starts, Zs, thetas, lambdas
 
 
-
 class Algorithm(object):
+
     "An object that applies the MEME algorithm to the sequences in a FASTA file."
 
     def __init__(self, options):
@@ -189,7 +192,6 @@ class Algorithm(object):
         self.options = options
         self.name = 'MEME'
 
-
     def __call__(self, fasta):
         "Run the method."
         start_time = time.time()
@@ -199,28 +201,29 @@ class Algorithm(object):
         predictions = []
 
         # run MEME
-        self.meme_cmd_args, self.stdoutdata, self.starts, self.Zs, self.thetas, self.lambdas = run_meme(fasta, self.options)
+        self.meme_cmd_args, self.stdoutdata, self.starts, self.Zs, self.thetas, self.lambdas = run_meme(
+            fasta, self.options)
 
         # parse output
         from Bio import Motif
         for motif in Motif.parse(open(os.path.join(self.options.output_dir, 'meme.txt')), "MEME"):
             for instance in motif.instances:
-                start = instance.start-1 # MEME parser seems to count from 1, not 0
-                prediction = instance.sequence_name, Interval(start, start + motif.length), instance.strand == '-'
+                # MEME parser seems to count from 1, not 0
+                start = instance.start - 1
+                prediction = instance.sequence_name, Interval(
+                    start, start + motif.length), instance.strand == '-'
                 predictions.append(prediction)
 
-        logger.info('MEME took %.1f seconds', time.time()-start_time)
+        logger.info('MEME took %.1f seconds', time.time() - start_time)
 
         return predictions
 
 
-
 def add_options(option_parser):
     "Add options for MEME to the option parser."
     pass
 
 
-
 if '__main__' == __name__:
 
     #
@@ -243,9 +246,10 @@ if '__main__' == __name__:
     predictions = method(fasta)
     from Bio.Motif.Parsers.MEME import MEMEParser
     parser = MEMEParser()
-    meme_output = parser.parse(open(os.path.join(options.output_dir, 'meme.txt')))
+    meme_output = parser.parse(
+        open(os.path.join(options.output_dir, 'meme.txt')))
 
-    # #Sequence, #start(inclusive), #end(inclusive), #nucleotides
+    # Sequence, #start(inclusive), #end(inclusive), #nucleotides
     # M00441-1-embl, 1531, 1543, ggccacgtcaccg
     f = sys.stdout
     print >> f, '#Sequence, start(inclusive), end(inclusive), nucleotides, p-value'
