@@ -205,8 +205,7 @@ def yield_pairs(occurrences, seq_infos, options):
         footprint1 = footprint(occ1)
         seq_length = seq_infos[occ1.seq].length
 
-        for i2 in xrange(i1, len(occurrences)):
-            occ2 = occurrences[i2]
+        for occ2 in occurrences[i1+1]:
 
             # only interested in occurrences on same sequence
             if occ2.seq != occ1.seq:
@@ -253,11 +252,14 @@ def make_pair_handler_from_primary_handler(primary_handler, ignore_close_to_end,
             primary_handler(
                 options.max_distance, occ1, occ2, distance, occ1.strand == '-', same_strand)
 
-        # handle occ2 as the primary occurrence
-        # check whether occ2 is too close to start or end to be a primary motif
-        if not ignore_close_to_end or can_be_primary(options.max_distance, footprint2, footprint1.size, seq_length):
-            primary_handler(
-                options.max_distance, occ2, occ1, distance, occ2.strand == '+', same_strand)
+        # don't handle occ2 as the primary occurrence if it is the same motif
+        # as the secondary occurrence
+        if occ1.motif != occ2.motif:
+            # handle occ2 as the primary occurrence
+            # check whether occ2 is too close to start or end to be a primary motif
+            if not ignore_close_to_end or can_be_primary(options.max_distance, footprint2, footprint1.size, seq_length):
+                primary_handler(
+                    options.max_distance, occ2, occ1, distance, occ2.strand == '+', same_strand)
 
     return handle_pair
 
@@ -269,8 +271,7 @@ def handle_pairs(occurrences, seq_infos, handler, options):
         footprint1 = footprint(occ1)
         seq_length = seq_infos[occ1.seq].length
 
-        for i2 in xrange(i1, len(occurrences)):
-            occ2 = occurrences[i2]
+        for occ2 in occurrences[i1+1:]:
 
             # only interested in occurrences on same sequence
             if occ2.seq != occ1.seq:
